# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/common.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x63\x61piscio/v1/common.proto\x12\x0b\x63\x61piscio.v1\"!\n\tTimestamp\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"$\n\x08\x44uration\x12\x18\n\x07seconds\x18\x01 \x01(\x03R\x07seconds\"2\n\x08KeyValue\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\xac\x01\n\x0fValidationIssue\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12;\n\x08severity\x18\x03 \x01(\x0e\x32\x1f.capiscio.v1.ValidationSeverityR\x08severity\x12\x12\n\x04\x63ode\x18\x04 \x01(\tR\x04\x63ode\x12\x18\n\x07\x64\x65tails\x18\x05 \x01(\tR\x07\x64\x65tails\"\x81\x01\n\x10ValidationResult\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x34\n\x06issues\x18\x02 \x03(\x0b\x32\x1c.capiscio.v1.ValidationIssueR\x06issues\x12!\n\x0cvalidated_at\x18\x03 \x01(\tR\x0bvalidatedAt\"\xbc\x01\n\x0b\x45rrorDetail\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x42\n\x08metadata\x18\x03 \x03(\x0b\x32&.capiscio.v1.ErrorDetail.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x97\x01\n\x12ValidationSeverity\x12#\n\x1fVALIDATION_SEVERITY_UNSPECIFIED\x10\x00\x12\x1c\n\x18VALIDATION_SEVERITY_INFO\x10\x01\x12\x1f\n\x1bVALIDATION_SEVERITY_WARNING\x10\x02\x12\x1d\n\x19VALIDATION_SEVERITY_ERROR\x10\x03*~\n\x06Rating\x12\x16\n\x12RATING_UNSPECIFIED\x10\x00\x12\x13\n\x0fRATING_CRITICAL\x10\x01\x12\x0f\n\x0bRATING_POOR\x10\x02\x12\x0f\n\x0bRATING_FAIR\x10\x03\x12\x0f\n\x0bRATING_GOOD\x10\x04\x12\x14\n\x10RATING_EXCELLENT\x10\x05\x42\xb1\x01\n\x0f\x63om.capiscio.v1B\x0b\x43ommonProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\013CommonProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_ERRORDETAIL_METADATAENTRY']._loaded_options = None
  _globals['_ERRORDETAIL_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATIONSEVERITY']._serialized_start=665
  _globals['_VALIDATIONSEVERITY']._serialized_end=816
  _globals['_RATING']._serialized_start=818
  _globals['_RATING']._serialized_end=944
  _globals['_TIMESTAMP']._serialized_start=41
  _globals['_TIMESTAMP']._serialized_end=74
  _globals['_DURATION']._serialized_start=76
  _globals['_DURATION']._serialized_end=112
  _globals['_KEYVALUE']._serialized_start=114
  _globals['_KEYVALUE']._serialized_end=164
  _globals['_VALIDATIONISSUE']._serialized_start=167
  _globals['_VALIDATIONISSUE']._serialized_end=339
  _globals['_VALIDATIONRESULT']._serialized_start=342
  _globals['_VALIDATIONRESULT']._serialized_end=471
  _globals['_ERRORDETAIL']._serialized_start=474
  _globals['_ERRORDETAIL']._serialized_end=662
  _globals['_ERRORDETAIL_METADATAENTRY']._serialized_start=603
  _globals['_ERRORDETAIL_METADATAENTRY']._serialized_end=662
# @@protoc_insertion_point(module_scope)
