# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/badge.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/badge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63\x61piscio/v1/badge.proto\x12\x0b\x63\x61piscio.v1\"\x92\x02\n\x0b\x42\x61\x64geClaims\x12\x10\n\x03jti\x18\x01 \x01(\tR\x03jti\x12\x10\n\x03iss\x18\x02 \x01(\tR\x03iss\x12\x10\n\x03sub\x18\x03 \x01(\tR\x03sub\x12\x10\n\x03iat\x18\x04 \x01(\x03R\x03iat\x12\x10\n\x03\x65xp\x18\x05 \x01(\x03R\x03\x65xp\x12\x10\n\x03nbf\x18\x06 \x01(\x03R\x03nbf\x12\x10\n\x03\x61ud\x18\x07 \x03(\tR\x03\x61ud\x12\x38\n\x0btrust_level\x18\x08 \x01(\x0e\x32\x17.capiscio.v1.TrustLevelR\ntrustLevel\x12\x16\n\x06\x64omain\x18\t \x01(\tR\x06\x64omain\x12\x1d\n\nagent_name\x18\n \x01(\tR\tagentName\x12\x14\n\x05scope\x18\x0b \x01(\tR\x05scope\"\x83\x01\n\x10SignBadgeRequest\x12\x30\n\x06\x63laims\x18\x01 \x01(\x0b\x32\x18.capiscio.v1.BadgeClaimsR\x06\x63laims\x12&\n\x0fprivate_key_jwk\x18\x02 \x01(\tR\rprivateKeyJwk\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\"[\n\x11SignBadgeResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x30\n\x06\x63laims\x18\x02 \x01(\x0b\x32\x18.capiscio.v1.BadgeClaimsR\x06\x63laims\"P\n\x12VerifyBadgeRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12$\n\x0epublic_key_jwk\x18\x02 \x01(\tR\x0cpublicKeyJwk\"\xb4\x03\n\rVerifyOptions\x12+\n\x04mode\x18\x01 \x01(\x0e\x32\x17.capiscio.v1.VerifyModeR\x04mode\x12\'\n\x0ftrusted_issuers\x18\x02 \x03(\tR\x0etrustedIssuers\x12\x1a\n\x08\x61udience\x18\x03 \x01(\tR\x08\x61udience\x12\'\n\x0fskip_revocation\x18\x04 \x01(\x08R\x0eskipRevocation\x12*\n\x11skip_agent_status\x18\x05 \x01(\x08R\x0fskipAgentStatus\x12\x36\n\x17\x63lock_tolerance_seconds\x18\x06 \x01(\x03R\x15\x63lockToleranceSeconds\x12!\n\x0cregistry_url\x18\x07 \x01(\tR\x0bregistryUrl\x12,\n\x12\x61\x63\x63\x65pt_self_signed\x18\x08 \x01(\x08R\x10\x61\x63\x63\x65ptSelfSigned\x12\x1b\n\tfail_open\x18\t \x01(\x08R\x08\x66\x61ilOpen\x12\x36\n\x17stale_threshold_seconds\x18\n \x01(\x03R\x15staleThresholdSeconds\"k\n\x1dVerifyBadgeWithOptionsRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x34\n\x07options\x18\x02 \x01(\x0b\x32\x1a.capiscio.v1.VerifyOptionsR\x07options\"\xf3\x01\n\x13VerifyBadgeResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x30\n\x06\x63laims\x18\x02 \x01(\x0b\x32\x18.capiscio.v1.BadgeClaimsR\x06\x63laims\x12\x34\n\tmode_used\x18\x03 \x01(\x0e\x32\x17.capiscio.v1.VerifyModeR\x08modeUsed\x12\x1a\n\x08warnings\x18\x04 \x03(\tR\x08warnings\x12\x1d\n\nerror_code\x18\x05 \x01(\tR\terrorCode\x12#\n\rerror_message\x18\x06 \x01(\tR\x0c\x65rrorMessage\")\n\x11ParseBadgeRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\"k\n\x12ParseBadgeResponse\x12\x30\n\x06\x63laims\x18\x01 \x01(\x0b\x32\x18.capiscio.v1.BadgeClaimsR\x06\x63laims\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\xef\x01\n\x13RequestBadgeRequest\x12\x19\n\x08\x61gent_id\x18\x01 \x01(\tR\x07\x61gentId\x12\x15\n\x06\x63\x61_url\x18\x02 \x01(\tR\x05\x63\x61Url\x12\x17\n\x07\x61pi_key\x18\x03 \x01(\tR\x06\x61piKey\x12\x16\n\x06\x64omain\x18\x04 \x01(\tR\x06\x64omain\x12\x1f\n\x0bttl_seconds\x18\x05 \x01(\x05R\nttlSeconds\x12\x38\n\x0btrust_level\x18\x06 \x01(\x0e\x32\x17.capiscio.v1.TrustLevelR\ntrustLevel\x12\x1a\n\x08\x61udience\x18\x07 \x03(\tR\x08\x61udience\"\x80\x02\n\x14RequestBadgeResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\x12\x10\n\x03jti\x18\x03 \x01(\tR\x03jti\x12\x18\n\x07subject\x18\x04 \x01(\tR\x07subject\x12\x38\n\x0btrust_level\x18\x05 \x01(\x0e\x32\x17.capiscio.v1.TrustLevelR\ntrustLevel\x12\x1d\n\nexpires_at\x18\x06 \x01(\x03R\texpiresAt\x12\x14\n\x05\x65rror\x18\x07 \x01(\tR\x05\x65rror\x12\x1d\n\nerror_code\x18\x08 \x01(\tR\terrorCode\"\xca\x01\n\x16RequestPoPBadgeRequest\x12\x1b\n\tagent_did\x18\x01 \x01(\tR\x08\x61gentDid\x12&\n\x0fprivate_key_jwk\x18\x02 \x01(\tR\rprivateKeyJwk\x12\x15\n\x06\x63\x61_url\x18\x03 \x01(\tR\x05\x63\x61Url\x12\x17\n\x07\x61pi_key\x18\x04 \x01(\tR\x06\x61piKey\x12\x1f\n\x0bttl_seconds\x18\x05 \x01(\x05R\nttlSeconds\x12\x1a\n\x08\x61udience\x18\x06 \x03(\tR\x08\x61udience\"\x8c\x03\n\x17RequestPoPBadgeResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\x12\x10\n\x03jti\x18\x03 \x01(\tR\x03jti\x12\x18\n\x07subject\x18\x04 \x01(\tR\x07subject\x12\x1f\n\x0btrust_level\x18\x05 \x01(\tR\ntrustLevel\x12\'\n\x0f\x61ssurance_level\x18\x06 \x01(\tR\x0e\x61ssuranceLevel\x12\x1d\n\nexpires_at\x18\x07 \x01(\x03R\texpiresAt\x12?\n\x03\x63nf\x18\x08 \x03(\x0b\x32-.capiscio.v1.RequestPoPBadgeResponse.CnfEntryR\x03\x63nf\x12\x14\n\x05\x65rror\x18\t \x01(\tR\x05\x65rror\x12\x1d\n\nerror_code\x18\n \x01(\tR\terrorCode\x1a\x36\n\x08\x43nfEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xb2\x03\n\x12StartKeeperRequest\x12+\n\x04mode\x18\x01 \x01(\x0e\x32\x17.capiscio.v1.KeeperModeR\x04mode\x12\x19\n\x08\x61gent_id\x18\x02 \x01(\tR\x07\x61gentId\x12\x15\n\x06\x63\x61_url\x18\x03 \x01(\tR\x05\x63\x61Url\x12\x17\n\x07\x61pi_key\x18\x04 \x01(\tR\x06\x61piKey\x12\x1f\n\x0boutput_file\x18\x05 \x01(\tR\noutputFile\x12\x1f\n\x0bttl_seconds\x18\x06 \x01(\x05R\nttlSeconds\x12\x30\n\x14renew_before_seconds\x18\x07 \x01(\x05R\x12renewBeforeSeconds\x12\x34\n\x16\x63heck_interval_seconds\x18\x08 \x01(\x05R\x14\x63heckIntervalSeconds\x12(\n\x10private_key_path\x18\t \x01(\tR\x0eprivateKeyPath\x12\x16\n\x06\x64omain\x18\n \x01(\tR\x06\x64omain\x12\x38\n\x0btrust_level\x18\x0b \x01(\x0e\x32\x17.capiscio.v1.TrustLevelR\ntrustLevel\"\xb8\x02\n\x0bKeeperEvent\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\x1c.capiscio.v1.KeeperEventTypeR\x04type\x12\x1b\n\tbadge_jti\x18\x02 \x01(\tR\x08\x62\x61\x64geJti\x12\x18\n\x07subject\x18\x03 \x01(\tR\x07subject\x12\x38\n\x0btrust_level\x18\x04 \x01(\x0e\x32\x17.capiscio.v1.TrustLevelR\ntrustLevel\x12\x1d\n\nexpires_at\x18\x05 \x01(\x03R\texpiresAt\x12\x14\n\x05\x65rror\x18\x06 \x01(\tR\x05\x65rror\x12\x1d\n\nerror_code\x18\x07 \x01(\tR\terrorCode\x12\x1c\n\ttimestamp\x18\x08 \x01(\x03R\ttimestamp\x12\x14\n\x05token\x18\t \x01(\tR\x05token\"~\n\x14\x43reateDVOrderRequest\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12%\n\x0e\x63hallenge_type\x18\x02 \x01(\tR\rchallengeType\x12\x10\n\x03jwk\x18\x03 \x01(\tR\x03jwk\x12\x15\n\x06\x63\x61_url\x18\x04 \x01(\tR\x05\x63\x61Url\"\xe6\x02\n\x15\x43reateDVOrderResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x19\n\x08order_id\x18\x02 \x01(\tR\x07orderId\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\x12%\n\x0e\x63hallenge_type\x18\x04 \x01(\tR\rchallengeType\x12\'\n\x0f\x63hallenge_token\x18\x05 \x01(\tR\x0e\x63hallengeToken\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12%\n\x0evalidation_url\x18\x07 \x01(\tR\rvalidationUrl\x12\x1d\n\ndns_record\x18\x08 \x01(\tR\tdnsRecord\x12\x1d\n\nexpires_at\x18\t \x01(\x03R\texpiresAt\x12\x14\n\x05\x65rror\x18\n \x01(\tR\x05\x65rror\x12\x1d\n\nerror_code\x18\x0b \x01(\tR\terrorCode\"E\n\x11GetDVOrderRequest\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x15\n\x06\x63\x61_url\x18\x02 \x01(\tR\x05\x63\x61Url\"\x86\x03\n\x12GetDVOrderResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x19\n\x08order_id\x18\x02 \x01(\tR\x07orderId\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\x12%\n\x0e\x63hallenge_type\x18\x04 \x01(\tR\rchallengeType\x12\'\n\x0f\x63hallenge_token\x18\x05 \x01(\tR\x0e\x63hallengeToken\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12%\n\x0evalidation_url\x18\x07 \x01(\tR\rvalidationUrl\x12\x1d\n\ndns_record\x18\x08 \x01(\tR\tdnsRecord\x12\x1d\n\nexpires_at\x18\t \x01(\x03R\texpiresAt\x12!\n\x0c\x66inalized_at\x18\n \x01(\x03R\x0b\x66inalizedAt\x12\x14\n\x05\x65rror\x18\x0b \x01(\tR\x05\x65rror\x12\x1d\n\nerror_code\x18\x0c \x01(\tR\terrorCode\"J\n\x16\x46inalizeDVOrderRequest\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x15\n\x06\x63\x61_url\x18\x02 \x01(\tR\x05\x63\x61Url\"\x9d\x01\n\x17\x46inalizeDVOrderResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x14\n\x05grant\x18\x02 \x01(\tR\x05grant\x12\x1d\n\nexpires_at\x18\x03 \x01(\x03R\texpiresAt\x12\x14\n\x05\x65rror\x18\x04 \x01(\tR\x05\x65rror\x12\x1d\n\nerror_code\x18\x05 \x01(\tR\terrorCode*\x96\x01\n\nTrustLevel\x12\x1b\n\x17TRUST_LEVEL_UNSPECIFIED\x10\x00\x12\x1b\n\x17TRUST_LEVEL_SELF_SIGNED\x10\x01\x12\x12\n\x0eTRUST_LEVEL_DV\x10\x02\x12\x12\n\x0eTRUST_LEVEL_OV\x10\x03\x12\x12\n\x0eTRUST_LEVEL_EV\x10\x04\x12\x12\n\x0eTRUST_LEVEL_CV\x10\x05*r\n\nVerifyMode\x12\x1b\n\x17VERIFY_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13VERIFY_MODE_OFFLINE\x10\x01\x12\x16\n\x12VERIFY_MODE_ONLINE\x10\x02\x12\x16\n\x12VERIFY_MODE_HYBRID\x10\x03*X\n\nKeeperMode\x12\x1b\n\x17KEEPER_MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eKEEPER_MODE_CA\x10\x01\x12\x19\n\x15KEEPER_MODE_SELF_SIGN\x10\x02*\x95\x01\n\x0fKeeperEventType\x12\x1c\n\x18KEEPER_EVENT_UNSPECIFIED\x10\x00\x12\x18\n\x14KEEPER_EVENT_STARTED\x10\x01\x12\x18\n\x14KEEPER_EVENT_RENEWED\x10\x02\x12\x16\n\x12KEEPER_EVENT_ERROR\x10\x03\x12\x18\n\x14KEEPER_EVENT_STOPPED\x10\x04\x32\xe7\x06\n\x0c\x42\x61\x64geService\x12J\n\tSignBadge\x12\x1d.capiscio.v1.SignBadgeRequest\x1a\x1e.capiscio.v1.SignBadgeResponse\x12P\n\x0bVerifyBadge\x12\x1f.capiscio.v1.VerifyBadgeRequest\x1a .capiscio.v1.VerifyBadgeResponse\x12\x66\n\x16VerifyBadgeWithOptions\x12*.capiscio.v1.VerifyBadgeWithOptionsRequest\x1a .capiscio.v1.VerifyBadgeResponse\x12M\n\nParseBadge\x12\x1e.capiscio.v1.ParseBadgeRequest\x1a\x1f.capiscio.v1.ParseBadgeResponse\x12S\n\x0cRequestBadge\x12 .capiscio.v1.RequestBadgeRequest\x1a!.capiscio.v1.RequestBadgeResponse\x12\\\n\x0fRequestPoPBadge\x12#.capiscio.v1.RequestPoPBadgeRequest\x1a$.capiscio.v1.RequestPoPBadgeResponse\x12V\n\rCreateDVOrder\x12!.capiscio.v1.CreateDVOrderRequest\x1a\".capiscio.v1.CreateDVOrderResponse\x12M\n\nGetDVOrder\x12\x1e.capiscio.v1.GetDVOrderRequest\x1a\x1f.capiscio.v1.GetDVOrderResponse\x12\\\n\x0f\x46inalizeDVOrder\x12#.capiscio.v1.FinalizeDVOrderRequest\x1a$.capiscio.v1.FinalizeDVOrderResponse\x12J\n\x0bStartKeeper\x12\x1f.capiscio.v1.StartKeeperRequest\x1a\x18.capiscio.v1.KeeperEvent0\x01\x42\xb0\x01\n\x0f\x63om.capiscio.v1B\nBadgeProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.badge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\nBadgeProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_REQUESTPOPBADGERESPONSE_CNFENTRY']._loaded_options = None
  _globals['_REQUESTPOPBADGERESPONSE_CNFENTRY']._serialized_options = b'8\001'
  _globals['_TRUSTLEVEL']._serialized_start=4619
  _globals['_TRUSTLEVEL']._serialized_end=4769
  _globals['_VERIFYMODE']._serialized_start=4771
  _globals['_VERIFYMODE']._serialized_end=4885
  _globals['_KEEPERMODE']._serialized_start=4887
  _globals['_KEEPERMODE']._serialized_end=4975
  _globals['_KEEPEREVENTTYPE']._serialized_start=4978
  _globals['_KEEPEREVENTTYPE']._serialized_end=5127
  _globals['_BADGECLAIMS']._serialized_start=41
  _globals['_BADGECLAIMS']._serialized_end=315
  _globals['_SIGNBADGEREQUEST']._serialized_start=318
  _globals['_SIGNBADGEREQUEST']._serialized_end=449
  _globals['_SIGNBADGERESPONSE']._serialized_start=451
  _globals['_SIGNBADGERESPONSE']._serialized_end=542
  _globals['_VERIFYBADGEREQUEST']._serialized_start=544
  _globals['_VERIFYBADGEREQUEST']._serialized_end=624
  _globals['_VERIFYOPTIONS']._serialized_start=627
  _globals['_VERIFYOPTIONS']._serialized_end=1063
  _globals['_VERIFYBADGEWITHOPTIONSREQUEST']._serialized_start=1065
  _globals['_VERIFYBADGEWITHOPTIONSREQUEST']._serialized_end=1172
  _globals['_VERIFYBADGERESPONSE']._serialized_start=1175
  _globals['_VERIFYBADGERESPONSE']._serialized_end=1418
  _globals['_PARSEBADGEREQUEST']._serialized_start=1420
  _globals['_PARSEBADGEREQUEST']._serialized_end=1461
  _globals['_PARSEBADGERESPONSE']._serialized_start=1463
  _globals['_PARSEBADGERESPONSE']._serialized_end=1570
  _globals['_REQUESTBADGEREQUEST']._serialized_start=1573
  _globals['_REQUESTBADGEREQUEST']._serialized_end=1812
  _globals['_REQUESTBADGERESPONSE']._serialized_start=1815
  _globals['_REQUESTBADGERESPONSE']._serialized_end=2071
  _globals['_REQUESTPOPBADGEREQUEST']._serialized_start=2074
  _globals['_REQUESTPOPBADGEREQUEST']._serialized_end=2276
  _globals['_REQUESTPOPBADGERESPONSE']._serialized_start=2279
  _globals['_REQUESTPOPBADGERESPONSE']._serialized_end=2675
  _globals['_REQUESTPOPBADGERESPONSE_CNFENTRY']._serialized_start=2621
  _globals['_REQUESTPOPBADGERESPONSE_CNFENTRY']._serialized_end=2675
  _globals['_STARTKEEPERREQUEST']._serialized_start=2678
  _globals['_STARTKEEPERREQUEST']._serialized_end=3112
  _globals['_KEEPEREVENT']._serialized_start=3115
  _globals['_KEEPEREVENT']._serialized_end=3427
  _globals['_CREATEDVORDERREQUEST']._serialized_start=3429
  _globals['_CREATEDVORDERREQUEST']._serialized_end=3555
  _globals['_CREATEDVORDERRESPONSE']._serialized_start=3558
  _globals['_CREATEDVORDERRESPONSE']._serialized_end=3916
  _globals['_GETDVORDERREQUEST']._serialized_start=3918
  _globals['_GETDVORDERREQUEST']._serialized_end=3987
  _globals['_GETDVORDERRESPONSE']._serialized_start=3990
  _globals['_GETDVORDERRESPONSE']._serialized_end=4380
  _globals['_FINALIZEDVORDERREQUEST']._serialized_start=4382
  _globals['_FINALIZEDVORDERREQUEST']._serialized_end=4456
  _globals['_FINALIZEDVORDERRESPONSE']._serialized_start=4459
  _globals['_FINALIZEDVORDERRESPONSE']._serialized_end=4616
  _globals['_BADGESERVICE']._serialized_start=5130
  _globals['_BADGESERVICE']._serialized_end=6001
# @@protoc_insertion_point(module_scope)
