# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/trust.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/trust.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capiscio_mcp._proto.gen.capiscio.v1 import common_pb2 as capiscio_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63\x61piscio/v1/trust.proto\x12\x0b\x63\x61piscio.v1\x1a\x18\x63\x61piscio/v1/common.proto\"\xa7\x03\n\nTrustedKey\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x37\n\talgorithm\x18\x03 \x01(\x0e\x32\x19.capiscio.v1.KeyAlgorithmR\talgorithm\x12\x1d\n\npublic_key\x18\x04 \x01(\x0cR\tpublicKey\x12.\n\x06\x66ormat\x18\x05 \x01(\x0e\x32\x16.capiscio.v1.KeyFormatR\x06\x66ormat\x12\x31\n\x08\x61\x64\x64\x65\x64_at\x18\x06 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\x07\x61\x64\x64\x65\x64\x41t\x12\x35\n\nexpires_at\x18\x07 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\texpiresAt\x12\x41\n\x08metadata\x18\x08 \x03(\x0b\x32%.capiscio.v1.TrustedKey.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xf3\x01\n\rAddKeyRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x1d\n\npublic_key\x18\x02 \x01(\x0cR\tpublicKey\x12.\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x16.capiscio.v1.KeyFormatR\x06\x66ormat\x12\x44\n\x08metadata\x18\x04 \x03(\x0b\x32(.capiscio.v1.AddKeyRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"L\n\x0e\x41\x64\x64KeyResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\";\n\x10RemoveKeyRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\"[\n\x11RemoveKeyResponse\x12!\n\x0ckeys_removed\x18\x01 \x01(\x05R\x0bkeysRemoved\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"8\n\rGetKeyRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\"`\n\x0eGetKeyResponse\x12)\n\x03key\x18\x01 \x01(\x0b\x32\x17.capiscio.v1.TrustedKeyR\x03key\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"^\n\x0fListKeysRequest\x12\x1d\n\ndid_filter\x18\x01 \x01(\tR\tdidFilter\x12\x14\n\x05limit\x18\x02 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x03 \x01(\tR\x06\x63ursor\"\x81\x01\n\x10ListKeysResponse\x12+\n\x04keys\x18\x01 \x03(\x0b\x32\x17.capiscio.v1.TrustedKeyR\x04keys\x12\x1f\n\x0bnext_cursor\x18\x02 \x01(\tR\nnextCursor\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\"$\n\x10IsTrustedRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\"]\n\x11IsTrustedResponse\x12\x1d\n\nis_trusted\x18\x01 \x01(\x08R\tisTrusted\x12)\n\x03key\x18\x02 \x01(\x0b\x32\x17.capiscio.v1.TrustedKeyR\x03key\"a\n\x1aImportFromDirectoryRequest\x12%\n\x0e\x64irectory_path\x18\x01 \x01(\tR\rdirectoryPath\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"}\n\x1bImportFromDirectoryResponse\x12#\n\rkeys_imported\x18\x01 \x01(\x05R\x0ckeysImported\x12!\n\x0ckeys_skipped\x18\x02 \x01(\x05R\x0bkeysSkipped\x12\x16\n\x06\x65rrors\x18\x03 \x03(\tR\x06\x65rrors\"q\n\x18\x45xportToDirectoryRequest\x12%\n\x0e\x64irectory_path\x18\x01 \x01(\tR\rdirectoryPath\x12.\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x16.capiscio.v1.KeyFormatR\x06\x66ormat\"e\n\x19\x45xportToDirectoryResponse\x12#\n\rkeys_exported\x18\x01 \x01(\x05R\x0ckeysExported\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\",\n\x10\x43learKeysRequest\x12\x18\n\x07\x63onfirm\x18\x01 \x01(\x08R\x07\x63onfirm\"6\n\x11\x43learKeysResponse\x12!\n\x0ckeys_cleared\x18\x01 \x01(\x05R\x0bkeysCleared*\xbc\x01\n\x0cKeyAlgorithm\x12\x1d\n\x19KEY_ALGORITHM_UNSPECIFIED\x10\x00\x12\x19\n\x15KEY_ALGORITHM_ED25519\x10\x01\x12\x1c\n\x18KEY_ALGORITHM_ECDSA_P256\x10\x02\x12\x1c\n\x18KEY_ALGORITHM_ECDSA_P384\x10\x03\x12\x1a\n\x16KEY_ALGORITHM_RSA_2048\x10\x04\x12\x1a\n\x16KEY_ALGORITHM_RSA_4096\x10\x05*c\n\tKeyFormat\x12\x1a\n\x16KEY_FORMAT_UNSPECIFIED\x10\x00\x12\x12\n\x0eKEY_FORMAT_JWK\x10\x01\x12\x12\n\x0eKEY_FORMAT_PEM\x10\x02\x12\x12\n\x0eKEY_FORMAT_DER\x10\x03\x32\x90\x05\n\x11TrustStoreService\x12\x41\n\x06\x41\x64\x64Key\x12\x1a.capiscio.v1.AddKeyRequest\x1a\x1b.capiscio.v1.AddKeyResponse\x12J\n\tRemoveKey\x12\x1d.capiscio.v1.RemoveKeyRequest\x1a\x1e.capiscio.v1.RemoveKeyResponse\x12\x41\n\x06GetKey\x12\x1a.capiscio.v1.GetKeyRequest\x1a\x1b.capiscio.v1.GetKeyResponse\x12G\n\x08ListKeys\x12\x1c.capiscio.v1.ListKeysRequest\x1a\x1d.capiscio.v1.ListKeysResponse\x12J\n\tIsTrusted\x12\x1d.capiscio.v1.IsTrustedRequest\x1a\x1e.capiscio.v1.IsTrustedResponse\x12h\n\x13ImportFromDirectory\x12\'.capiscio.v1.ImportFromDirectoryRequest\x1a(.capiscio.v1.ImportFromDirectoryResponse\x12\x62\n\x11\x45xportToDirectory\x12%.capiscio.v1.ExportToDirectoryRequest\x1a&.capiscio.v1.ExportToDirectoryResponse\x12\x46\n\x05\x43lear\x12\x1d.capiscio.v1.ClearKeysRequest\x1a\x1e.capiscio.v1.ClearKeysResponseB\xb0\x01\n\x0f\x63om.capiscio.v1B\nTrustProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.trust_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\nTrustProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_TRUSTEDKEY_METADATAENTRY']._loaded_options = None
  _globals['_TRUSTEDKEY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ADDKEYREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_ADDKEYREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_KEYALGORITHM']._serialized_start=2034
  _globals['_KEYALGORITHM']._serialized_end=2222
  _globals['_KEYFORMAT']._serialized_start=2224
  _globals['_KEYFORMAT']._serialized_end=2323
  _globals['_TRUSTEDKEY']._serialized_start=67
  _globals['_TRUSTEDKEY']._serialized_end=490
  _globals['_TRUSTEDKEY_METADATAENTRY']._serialized_start=431
  _globals['_TRUSTEDKEY_METADATAENTRY']._serialized_end=490
  _globals['_ADDKEYREQUEST']._serialized_start=493
  _globals['_ADDKEYREQUEST']._serialized_end=736
  _globals['_ADDKEYREQUEST_METADATAENTRY']._serialized_start=431
  _globals['_ADDKEYREQUEST_METADATAENTRY']._serialized_end=490
  _globals['_ADDKEYRESPONSE']._serialized_start=738
  _globals['_ADDKEYRESPONSE']._serialized_end=814
  _globals['_REMOVEKEYREQUEST']._serialized_start=816
  _globals['_REMOVEKEYREQUEST']._serialized_end=875
  _globals['_REMOVEKEYRESPONSE']._serialized_start=877
  _globals['_REMOVEKEYRESPONSE']._serialized_end=968
  _globals['_GETKEYREQUEST']._serialized_start=970
  _globals['_GETKEYREQUEST']._serialized_end=1026
  _globals['_GETKEYRESPONSE']._serialized_start=1028
  _globals['_GETKEYRESPONSE']._serialized_end=1124
  _globals['_LISTKEYSREQUEST']._serialized_start=1126
  _globals['_LISTKEYSREQUEST']._serialized_end=1220
  _globals['_LISTKEYSRESPONSE']._serialized_start=1223
  _globals['_LISTKEYSRESPONSE']._serialized_end=1352
  _globals['_ISTRUSTEDREQUEST']._serialized_start=1354
  _globals['_ISTRUSTEDREQUEST']._serialized_end=1390
  _globals['_ISTRUSTEDRESPONSE']._serialized_start=1392
  _globals['_ISTRUSTEDRESPONSE']._serialized_end=1485
  _globals['_IMPORTFROMDIRECTORYREQUEST']._serialized_start=1487
  _globals['_IMPORTFROMDIRECTORYREQUEST']._serialized_end=1584
  _globals['_IMPORTFROMDIRECTORYRESPONSE']._serialized_start=1586
  _globals['_IMPORTFROMDIRECTORYRESPONSE']._serialized_end=1711
  _globals['_EXPORTTODIRECTORYREQUEST']._serialized_start=1713
  _globals['_EXPORTTODIRECTORYREQUEST']._serialized_end=1826
  _globals['_EXPORTTODIRECTORYRESPONSE']._serialized_start=1828
  _globals['_EXPORTTODIRECTORYRESPONSE']._serialized_end=1929
  _globals['_CLEARKEYSREQUEST']._serialized_start=1931
  _globals['_CLEARKEYSREQUEST']._serialized_end=1975
  _globals['_CLEARKEYSRESPONSE']._serialized_start=1977
  _globals['_CLEARKEYSRESPONSE']._serialized_end=2031
  _globals['_TRUSTSTORESERVICE']._serialized_start=2326
  _globals['_TRUSTSTORESERVICE']._serialized_end=2982
# @@protoc_insertion_point(module_scope)
