# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/scoring.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/scoring.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capiscio_mcp._proto.gen.capiscio.v1 import common_pb2 as capiscio_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63\x61piscio/v1/scoring.proto\x12\x0b\x63\x61piscio.v1\x1a\x18\x63\x61piscio/v1/common.proto\"\xf3\x01\n\x04Rule\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x36\n\x08\x63\x61tegory\x18\x04 \x01(\x0e\x32\x1a.capiscio.v1.ScoreCategoryR\x08\x63\x61tegory\x12\x35\n\x08severity\x18\x05 \x01(\x0e\x32\x19.capiscio.v1.RuleSeverityR\x08severity\x12\x16\n\x06weight\x18\x06 \x01(\x05R\x06weight\x12\x1e\n\nexpression\x18\x07 \x01(\tR\nexpression\"\x8f\x02\n\x07RuleSet\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\'\n\x05rules\x18\x05 \x03(\x0b\x32\x11.capiscio.v1.RuleR\x05rules\x12>\n\x08metadata\x18\x06 \x03(\x0b\x32\".capiscio.v1.RuleSet.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x82\x02\n\nRuleResult\x12\x17\n\x07rule_id\x18\x01 \x01(\tR\x06ruleId\x12\x16\n\x06passed\x18\x02 \x01(\x08R\x06passed\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12-\n\x12score_contribution\x18\x04 \x01(\x01R\x11scoreContribution\x12>\n\x07\x64\x65tails\x18\x05 \x03(\x0b\x32$.capiscio.v1.RuleResult.DetailsEntryR\x07\x64\x65tails\x1a:\n\x0c\x44\x65tailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd6\x01\n\rCategoryScore\x12\x36\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32\x1a.capiscio.v1.ScoreCategoryR\x08\x63\x61tegory\x12\x14\n\x05score\x18\x02 \x01(\x01R\x05score\x12!\n\x0crules_passed\x18\x03 \x01(\x05R\x0brulesPassed\x12!\n\x0crules_failed\x18\x04 \x01(\x05R\x0brulesFailed\x12\x31\n\x07results\x18\x05 \x03(\x0b\x32\x17.capiscio.v1.RuleResultR\x07results\"\x97\x03\n\rScoringResult\x12#\n\roverall_score\x18\x01 \x01(\x01R\x0coverallScore\x12+\n\x06rating\x18\x02 \x01(\x0e\x32\x13.capiscio.v1.RatingR\x06rating\x12:\n\ncategories\x18\x03 \x03(\x0b\x32\x1a.capiscio.v1.CategoryScoreR\ncategories\x12:\n\x0crule_results\x18\x04 \x03(\x0b\x32\x17.capiscio.v1.RuleResultR\x0bruleResults\x12=\n\nvalidation\x18\x05 \x01(\x0b\x32\x1d.capiscio.v1.ValidationResultR\nvalidation\x12\x33\n\tscored_at\x18\x06 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\x08scoredAt\x12\x1e\n\x0brule_set_id\x18\x07 \x01(\tR\truleSetId\x12(\n\x10rule_set_version\x18\x08 \x01(\tR\x0eruleSetVersion\"\x9b\x01\n\x15ScoreAgentCardRequest\x12&\n\x0f\x61gent_card_json\x18\x01 \x01(\tR\ragentCardJson\x12\x1e\n\x0brule_set_id\x18\x02 \x01(\tR\truleSetId\x12:\n\ncategories\x18\x03 \x03(\x0e\x32\x1a.capiscio.v1.ScoreCategoryR\ncategories\"q\n\x16ScoreAgentCardResponse\x12\x32\n\x06result\x18\x01 \x01(\x0b\x32\x1a.capiscio.v1.ScoringResultR\x06result\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"V\n\x13ValidateRuleRequest\x12\x17\n\x07rule_id\x18\x01 \x01(\tR\x06ruleId\x12&\n\x0f\x61gent_card_json\x18\x02 \x01(\tR\ragentCardJson\"l\n\x14ValidateRuleResponse\x12/\n\x06result\x18\x01 \x01(\x0b\x32\x17.capiscio.v1.RuleResultR\x06result\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"C\n\x13ListRuleSetsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\"j\n\x14ListRuleSetsResponse\x12\x31\n\trule_sets\x18\x01 \x03(\x0b\x32\x14.capiscio.v1.RuleSetR\x08ruleSets\x12\x1f\n\x0bnext_cursor\x18\x02 \x01(\tR\nnextCursor\"=\n\x11GetRuleSetRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\"j\n\x12GetRuleSetResponse\x12/\n\x08rule_set\x18\x01 \x01(\x0b\x32\x14.capiscio.v1.RuleSetR\x07ruleSet\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"}\n\x16\x41ggregateScoresRequest\x12\x34\n\x07results\x18\x01 \x03(\x0b\x32\x1a.capiscio.v1.ScoringResultR\x07results\x12-\n\x12\x61ggregation_method\x18\x02 \x01(\tR\x11\x61ggregationMethod\"\xb8\x02\n\x17\x41ggregateScoresResponse\x12\'\n\x0f\x61ggregate_score\x18\x01 \x01(\x01R\x0e\x61ggregateScore\x12>\n\x10\x61ggregate_rating\x18\x02 \x01(\x0e\x32\x13.capiscio.v1.RatingR\x0f\x61ggregateRating\x12m\n\x13\x63\x61tegory_aggregates\x18\x03 \x03(\x0b\x32<.capiscio.v1.AggregateScoresResponse.CategoryAggregatesEntryR\x12\x63\x61tegoryAggregates\x1a\x45\n\x17\x43\x61tegoryAggregatesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01*\xca\x01\n\rScoreCategory\x12\x1e\n\x1aSCORE_CATEGORY_UNSPECIFIED\x10\x00\x12\x1b\n\x17SCORE_CATEGORY_IDENTITY\x10\x01\x12\x1f\n\x1bSCORE_CATEGORY_CAPABILITIES\x10\x02\x12\x1b\n\x17SCORE_CATEGORY_SECURITY\x10\x03\x12\x1d\n\x19SCORE_CATEGORY_COMPLIANCE\x10\x04\x12\x1f\n\x1bSCORE_CATEGORY_TRANSPARENCY\x10\x05*\x95\x01\n\x0cRuleSeverity\x12\x1d\n\x19RULE_SEVERITY_UNSPECIFIED\x10\x00\x12\x16\n\x12RULE_SEVERITY_INFO\x10\x01\x12\x19\n\x15RULE_SEVERITY_WARNING\x10\x02\x12\x17\n\x13RULE_SEVERITY_ERROR\x10\x03\x12\x1a\n\x16RULE_SEVERITY_CRITICAL\x10\x04\x32\xc2\x03\n\x0eScoringService\x12Y\n\x0eScoreAgentCard\x12\".capiscio.v1.ScoreAgentCardRequest\x1a#.capiscio.v1.ScoreAgentCardResponse\x12S\n\x0cValidateRule\x12 .capiscio.v1.ValidateRuleRequest\x1a!.capiscio.v1.ValidateRuleResponse\x12S\n\x0cListRuleSets\x12 .capiscio.v1.ListRuleSetsRequest\x1a!.capiscio.v1.ListRuleSetsResponse\x12M\n\nGetRuleSet\x12\x1e.capiscio.v1.GetRuleSetRequest\x1a\x1f.capiscio.v1.GetRuleSetResponse\x12\\\n\x0f\x41ggregateScores\x12#.capiscio.v1.AggregateScoresRequest\x1a$.capiscio.v1.AggregateScoresResponseB\xb2\x01\n\x0f\x63om.capiscio.v1B\x0cScoringProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.scoring_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\014ScoringProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_RULESET_METADATAENTRY']._loaded_options = None
  _globals['_RULESET_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_RULERESULT_DETAILSENTRY']._loaded_options = None
  _globals['_RULERESULT_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_AGGREGATESCORESRESPONSE_CATEGORYAGGREGATESENTRY']._loaded_options = None
  _globals['_AGGREGATESCORESRESPONSE_CATEGORYAGGREGATESENTRY']._serialized_options = b'8\001'
  _globals['_SCORECATEGORY']._serialized_start=2738
  _globals['_SCORECATEGORY']._serialized_end=2940
  _globals['_RULESEVERITY']._serialized_start=2943
  _globals['_RULESEVERITY']._serialized_end=3092
  _globals['_RULE']._serialized_start=69
  _globals['_RULE']._serialized_end=312
  _globals['_RULESET']._serialized_start=315
  _globals['_RULESET']._serialized_end=586
  _globals['_RULESET_METADATAENTRY']._serialized_start=527
  _globals['_RULESET_METADATAENTRY']._serialized_end=586
  _globals['_RULERESULT']._serialized_start=589
  _globals['_RULERESULT']._serialized_end=847
  _globals['_RULERESULT_DETAILSENTRY']._serialized_start=789
  _globals['_RULERESULT_DETAILSENTRY']._serialized_end=847
  _globals['_CATEGORYSCORE']._serialized_start=850
  _globals['_CATEGORYSCORE']._serialized_end=1064
  _globals['_SCORINGRESULT']._serialized_start=1067
  _globals['_SCORINGRESULT']._serialized_end=1474
  _globals['_SCOREAGENTCARDREQUEST']._serialized_start=1477
  _globals['_SCOREAGENTCARDREQUEST']._serialized_end=1632
  _globals['_SCOREAGENTCARDRESPONSE']._serialized_start=1634
  _globals['_SCOREAGENTCARDRESPONSE']._serialized_end=1747
  _globals['_VALIDATERULEREQUEST']._serialized_start=1749
  _globals['_VALIDATERULEREQUEST']._serialized_end=1835
  _globals['_VALIDATERULERESPONSE']._serialized_start=1837
  _globals['_VALIDATERULERESPONSE']._serialized_end=1945
  _globals['_LISTRULESETSREQUEST']._serialized_start=1947
  _globals['_LISTRULESETSREQUEST']._serialized_end=2014
  _globals['_LISTRULESETSRESPONSE']._serialized_start=2016
  _globals['_LISTRULESETSRESPONSE']._serialized_end=2122
  _globals['_GETRULESETREQUEST']._serialized_start=2124
  _globals['_GETRULESETREQUEST']._serialized_end=2185
  _globals['_GETRULESETRESPONSE']._serialized_start=2187
  _globals['_GETRULESETRESPONSE']._serialized_end=2293
  _globals['_AGGREGATESCORESREQUEST']._serialized_start=2295
  _globals['_AGGREGATESCORESREQUEST']._serialized_end=2420
  _globals['_AGGREGATESCORESRESPONSE']._serialized_start=2423
  _globals['_AGGREGATESCORESRESPONSE']._serialized_end=2735
  _globals['_AGGREGATESCORESRESPONSE_CATEGORYAGGREGATESENTRY']._serialized_start=2666
  _globals['_AGGREGATESCORESRESPONSE_CATEGORYAGGREGATESENTRY']._serialized_end=2735
  _globals['_SCORINGSERVICE']._serialized_start=3095
  _globals['_SCORINGSERVICE']._serialized_end=3545
# @@protoc_insertion_point(module_scope)
