# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/registry.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capiscio_mcp._proto.gen.capiscio.v1 import common_pb2 as capiscio_dot_v1_dot_common__pb2
from capiscio_mcp._proto.gen.capiscio.v1 import badge_pb2 as capiscio_dot_v1_dot_badge__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63\x61piscio/v1/registry.proto\x12\x0b\x63\x61piscio.v1\x1a\x18\x63\x61piscio/v1/common.proto\x1a\x17\x63\x61piscio/v1/badge.proto\"\xc1\x04\n\x0fRegisteredAgent\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12&\n\x0f\x61gent_card_json\x18\x04 \x01(\tR\ragentCardJson\x12\x30\n\x06status\x18\x05 \x01(\x0e\x32\x18.capiscio.v1.AgentStatusR\x06status\x12.\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32\x18.capiscio.v1.BadgeClaimsR\x05\x62\x61\x64ge\x12+\n\x06rating\x18\x07 \x01(\x0e\x32\x13.capiscio.v1.RatingR\x06rating\x12;\n\rregistered_at\x18\x08 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\x0cregisteredAt\x12\x35\n\nupdated_at\x18\t \x01(\x0b\x32\x16.capiscio.v1.TimestampR\tupdatedAt\x12\"\n\x0c\x63\x61pabilities\x18\n \x03(\tR\x0c\x63\x61pabilities\x12\x12\n\x04tags\x18\x0b \x03(\tR\x04tags\x12\x46\n\x08metadata\x18\x0c \x03(\x0b\x32*.capiscio.v1.RegisteredAgent.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"k\n\x0fGetAgentRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12#\n\rinclude_badge\x18\x02 \x01(\x08R\x0cincludeBadge\x12!\n\x0cverify_badge\x18\x03 \x01(\x08R\x0bverifyBadge\"\x8c\x01\n\x10GetAgentResponse\x12\x32\n\x05\x61gent\x18\x01 \x01(\x0b\x32\x1c.capiscio.v1.RegisteredAgentR\x05\x61gent\x12\x1f\n\x0b\x62\x61\x64ge_valid\x18\x02 \x01(\x08R\nbadgeValid\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"\xff\x02\n\x13SearchAgentsRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\"\n\x0c\x63\x61pabilities\x18\x02 \x03(\tR\x0c\x63\x61pabilities\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12\x37\n\x08operator\x18\x04 \x01(\x0e\x32\x1b.capiscio.v1.SearchOperatorR\x08operator\x12\x32\n\nmin_rating\x18\x05 \x01(\x0e\x32\x13.capiscio.v1.RatingR\tminRating\x12=\n\rstatus_filter\x18\x06 \x01(\x0e\x32\x18.capiscio.v1.AgentStatusR\x0cstatusFilter\x12\x14\n\x05limit\x18\x07 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x08 \x01(\tR\x06\x63ursor\x12\x17\n\x07sort_by\x18\t \x01(\tR\x06sortBy\x12\'\n\x0fsort_descending\x18\n \x01(\x08R\x0esortDescending\"\x8e\x01\n\x14SearchAgentsResponse\x12\x34\n\x06\x61gents\x18\x01 \x03(\x0b\x32\x1c.capiscio.v1.RegisteredAgentR\x06\x61gents\x12\x1f\n\x0bnext_cursor\x18\x02 \x01(\tR\nnextCursor\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\"\xff\x01\n\x14RegisterAgentRequest\x12&\n\x0f\x61gent_card_json\x18\x01 \x01(\tR\ragentCardJson\x12!\n\x0csigned_badge\x18\x02 \x01(\tR\x0bsignedBadge\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12K\n\x08metadata\x18\x04 \x03(\x0b\x32/.capiscio.v1.RegisterAgentRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x80\x01\n\x15RegisterAgentResponse\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x30\n\x06status\x18\x02 \x01(\x0e\x32\x18.capiscio.v1.AgentStatusR\x06status\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"\x8d\x02\n\x12UpdateAgentRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12&\n\x0f\x61gent_card_json\x18\x02 \x01(\tR\ragentCardJson\x12!\n\x0csigned_badge\x18\x03 \x01(\tR\x0bsignedBadge\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32-.capiscio.v1.UpdateAgentRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"n\n\x13UpdateAgentResponse\x12\x32\n\x05\x61gent\x18\x01 \x01(\x0b\x32\x1c.capiscio.v1.RegisteredAgentR\x05\x61gent\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"B\n\x16\x44\x65registerAgentRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"X\n\x17\x44\x65registerAgentResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"q\n\x19VerifyRegistrationRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12!\n\x0cverify_badge\x18\x02 \x01(\x08R\x0bverifyBadge\x12\x1f\n\x0bverify_keys\x18\x03 \x01(\x08R\nverifyKeys\"\xe5\x01\n\x1aVerifyRegistrationResponse\x12#\n\ris_registered\x18\x01 \x01(\x08R\x0cisRegistered\x12\x1f\n\x0b\x62\x61\x64ge_valid\x18\x02 \x01(\x08R\nbadgeValid\x12\x1d\n\nkeys_valid\x18\x03 \x01(\x08R\tkeysValid\x12=\n\nvalidation\x18\x04 \x01(\x0b\x32\x1d.capiscio.v1.ValidationResultR\nvalidation\x12#\n\rerror_message\x18\x05 \x01(\tR\x0c\x65rrorMessage\"\x80\x01\n\x11ListAgentsRequest\x12=\n\rstatus_filter\x18\x01 \x01(\x0e\x32\x18.capiscio.v1.AgentStatusR\x0cstatusFilter\x12\x14\n\x05limit\x18\x02 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x03 \x01(\tR\x06\x63ursor\"\x8c\x01\n\x12ListAgentsResponse\x12\x34\n\x06\x61gents\x18\x01 \x03(\x0b\x32\x1c.capiscio.v1.RegisteredAgentR\x06\x61gents\x12\x1f\n\x0bnext_cursor\x18\x02 \x01(\tR\nnextCursor\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\"\x11\n\x0fGetStatsRequest\"\x85\x05\n\x10GetStatsResponse\x12!\n\x0ctotal_agents\x18\x01 \x01(\x05R\x0btotalAgents\x12#\n\ractive_agents\x18\x02 \x01(\x05R\x0c\x61\x63tiveAgents\x12\'\n\x0finactive_agents\x18\x03 \x01(\x05R\x0einactiveAgents\x12)\n\x10suspended_agents\x18\x04 \x01(\x05R\x0fsuspendedAgents\x12%\n\x0epending_agents\x18\x05 \x01(\x05R\rpendingAgents\x12#\n\rbadged_agents\x18\x06 \x01(\x05R\x0c\x62\x61\x64gedAgents\x12[\n\x10\x61gents_by_rating\x18\x07 \x03(\x0b\x32\x31.capiscio.v1.GetStatsResponse.AgentsByRatingEntryR\x0e\x61gentsByRating\x12g\n\x14\x61gents_by_capability\x18\x08 \x03(\x0b\x32\x35.capiscio.v1.GetStatsResponse.AgentsByCapabilityEntryR\x12\x61gentsByCapability\x12\x39\n\x0clast_updated\x18\t \x01(\x0b\x32\x16.capiscio.v1.TimestampR\x0blastUpdated\x1a\x41\n\x13\x41gentsByRatingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x1a\x45\n\x17\x41gentsByCapabilityEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"\r\n\x0bPingRequest\"y\n\x0cPingResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x37\n\x0bserver_time\x18\x03 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\nserverTime*\x95\x01\n\x0b\x41gentStatus\x12\x1c\n\x18\x41GENT_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41GENT_STATUS_ACTIVE\x10\x01\x12\x19\n\x15\x41GENT_STATUS_INACTIVE\x10\x02\x12\x1a\n\x16\x41GENT_STATUS_SUSPENDED\x10\x03\x12\x18\n\x14\x41GENT_STATUS_PENDING\x10\x04*b\n\x0eSearchOperator\x12\x1f\n\x1bSEARCH_OPERATOR_UNSPECIFIED\x10\x00\x12\x17\n\x13SEARCH_OPERATOR_AND\x10\x01\x12\x16\n\x12SEARCH_OPERATOR_OR\x10\x02\x32\xf3\x05\n\x0fRegistryService\x12G\n\x08GetAgent\x12\x1c.capiscio.v1.GetAgentRequest\x1a\x1d.capiscio.v1.GetAgentResponse\x12S\n\x0cSearchAgents\x12 .capiscio.v1.SearchAgentsRequest\x1a!.capiscio.v1.SearchAgentsResponse\x12V\n\rRegisterAgent\x12!.capiscio.v1.RegisterAgentRequest\x1a\".capiscio.v1.RegisterAgentResponse\x12P\n\x0bUpdateAgent\x12\x1f.capiscio.v1.UpdateAgentRequest\x1a .capiscio.v1.UpdateAgentResponse\x12\\\n\x0f\x44\x65registerAgent\x12#.capiscio.v1.DeregisterAgentRequest\x1a$.capiscio.v1.DeregisterAgentResponse\x12\x65\n\x12VerifyRegistration\x12&.capiscio.v1.VerifyRegistrationRequest\x1a\'.capiscio.v1.VerifyRegistrationResponse\x12M\n\nListAgents\x12\x1e.capiscio.v1.ListAgentsRequest\x1a\x1f.capiscio.v1.ListAgentsResponse\x12G\n\x08GetStats\x12\x1c.capiscio.v1.GetStatsRequest\x1a\x1d.capiscio.v1.GetStatsResponse\x12;\n\x04Ping\x12\x18.capiscio.v1.PingRequest\x1a\x19.capiscio.v1.PingResponseB\xb3\x01\n\x0f\x63om.capiscio.v1B\rRegistryProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\rRegistryProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_REGISTEREDAGENT_METADATAENTRY']._loaded_options = None
  _globals['_REGISTEREDAGENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERAGENTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_REGISTERAGENTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEAGENTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATSRESPONSE_AGENTSBYRATINGENTRY']._loaded_options = None
  _globals['_GETSTATSRESPONSE_AGENTSBYRATINGENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATSRESPONSE_AGENTSBYCAPABILITYENTRY']._loaded_options = None
  _globals['_GETSTATSRESPONSE_AGENTSBYCAPABILITYENTRY']._serialized_options = b'8\001'
  _globals['_AGENTSTATUS']._serialized_start=3815
  _globals['_AGENTSTATUS']._serialized_end=3964
  _globals['_SEARCHOPERATOR']._serialized_start=3966
  _globals['_SEARCHOPERATOR']._serialized_end=4064
  _globals['_REGISTEREDAGENT']._serialized_start=95
  _globals['_REGISTEREDAGENT']._serialized_end=672
  _globals['_REGISTEREDAGENT_METADATAENTRY']._serialized_start=613
  _globals['_REGISTEREDAGENT_METADATAENTRY']._serialized_end=672
  _globals['_GETAGENTREQUEST']._serialized_start=674
  _globals['_GETAGENTREQUEST']._serialized_end=781
  _globals['_GETAGENTRESPONSE']._serialized_start=784
  _globals['_GETAGENTRESPONSE']._serialized_end=924
  _globals['_SEARCHAGENTSREQUEST']._serialized_start=927
  _globals['_SEARCHAGENTSREQUEST']._serialized_end=1310
  _globals['_SEARCHAGENTSRESPONSE']._serialized_start=1313
  _globals['_SEARCHAGENTSRESPONSE']._serialized_end=1455
  _globals['_REGISTERAGENTREQUEST']._serialized_start=1458
  _globals['_REGISTERAGENTREQUEST']._serialized_end=1713
  _globals['_REGISTERAGENTREQUEST_METADATAENTRY']._serialized_start=613
  _globals['_REGISTERAGENTREQUEST_METADATAENTRY']._serialized_end=672
  _globals['_REGISTERAGENTRESPONSE']._serialized_start=1716
  _globals['_REGISTERAGENTRESPONSE']._serialized_end=1844
  _globals['_UPDATEAGENTREQUEST']._serialized_start=1847
  _globals['_UPDATEAGENTREQUEST']._serialized_end=2116
  _globals['_UPDATEAGENTREQUEST_METADATAENTRY']._serialized_start=613
  _globals['_UPDATEAGENTREQUEST_METADATAENTRY']._serialized_end=672
  _globals['_UPDATEAGENTRESPONSE']._serialized_start=2118
  _globals['_UPDATEAGENTRESPONSE']._serialized_end=2228
  _globals['_DEREGISTERAGENTREQUEST']._serialized_start=2230
  _globals['_DEREGISTERAGENTREQUEST']._serialized_end=2296
  _globals['_DEREGISTERAGENTRESPONSE']._serialized_start=2298
  _globals['_DEREGISTERAGENTRESPONSE']._serialized_end=2386
  _globals['_VERIFYREGISTRATIONREQUEST']._serialized_start=2388
  _globals['_VERIFYREGISTRATIONREQUEST']._serialized_end=2501
  _globals['_VERIFYREGISTRATIONRESPONSE']._serialized_start=2504
  _globals['_VERIFYREGISTRATIONRESPONSE']._serialized_end=2733
  _globals['_LISTAGENTSREQUEST']._serialized_start=2736
  _globals['_LISTAGENTSREQUEST']._serialized_end=2864
  _globals['_LISTAGENTSRESPONSE']._serialized_start=2867
  _globals['_LISTAGENTSRESPONSE']._serialized_end=3007
  _globals['_GETSTATSREQUEST']._serialized_start=3009
  _globals['_GETSTATSREQUEST']._serialized_end=3026
  _globals['_GETSTATSRESPONSE']._serialized_start=3029
  _globals['_GETSTATSRESPONSE']._serialized_end=3674
  _globals['_GETSTATSRESPONSE_AGENTSBYRATINGENTRY']._serialized_start=3538
  _globals['_GETSTATSRESPONSE_AGENTSBYRATINGENTRY']._serialized_end=3603
  _globals['_GETSTATSRESPONSE_AGENTSBYCAPABILITYENTRY']._serialized_start=3605
  _globals['_GETSTATSRESPONSE_AGENTSBYCAPABILITYENTRY']._serialized_end=3674
  _globals['_PINGREQUEST']._serialized_start=3676
  _globals['_PINGREQUEST']._serialized_end=3689
  _globals['_PINGRESPONSE']._serialized_start=3691
  _globals['_PINGRESPONSE']._serialized_end=3812
  _globals['_REGISTRYSERVICE']._serialized_start=4067
  _globals['_REGISTRYSERVICE']._serialized_end=4822
# @@protoc_insertion_point(module_scope)
