# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/revocation.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/revocation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capiscio_mcp._proto.gen.capiscio.v1 import common_pb2 as capiscio_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63\x61piscio/v1/revocation.proto\x12\x0b\x63\x61piscio.v1\x1a\x18\x63\x61piscio/v1/common.proto\"\x82\x02\n\x0fRevocationEntry\x12\x18\n\x07subject\x18\x01 \x01(\tR\x07subject\x12\x35\n\x06reason\x18\x02 \x01(\x0e\x32\x1d.capiscio.v1.RevocationReasonR\x06reason\x12\x35\n\nrevoked_at\x18\x03 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\trevokedAt\x12\x35\n\nexpires_at\x18\x04 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\texpiresAt\x12\x16\n\x06issuer\x18\x05 \x01(\tR\x06issuer\x12\x18\n\x07\x63omment\x18\x06 \x01(\tR\x07\x63omment\"\x80\x01\n\x10IsRevokedRequest\x12\x18\n\x07subject\x18\x01 \x01(\tR\x07subject\x12/\n\x07\x61t_time\x18\x02 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\x06\x61tTime\x12!\n\x0c\x63heck_remote\x18\x03 \x01(\x08R\x0b\x63heckRemote\"~\n\x11IsRevokedResponse\x12\x1d\n\nis_revoked\x18\x01 \x01(\x08R\tisRevoked\x12\x32\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x1c.capiscio.v1.RevocationEntryR\x05\x65ntry\x12\x16\n\x06source\x18\x03 \x01(\tR\x06source\"z\n\rRevokeRequest\x12\x18\n\x07subject\x18\x01 \x01(\tR\x07subject\x12\x35\n\x06reason\x18\x02 \x01(\x0e\x32\x1d.capiscio.v1.RevocationReasonR\x06reason\x12\x18\n\x07\x63omment\x18\x03 \x01(\tR\x07\x63omment\"i\n\x0eRevokeResponse\x12\x32\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x1c.capiscio.v1.RevocationEntryR\x05\x65ntry\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"+\n\x0fUnrevokeRequest\x12\x18\n\x07subject\x18\x01 \x01(\tR\x07subject\"X\n\x10UnrevokeResponse\x12\x1f\n\x0bwas_revoked\x18\x01 \x01(\x08R\nwasRevoked\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\xb1\x01\n\x16ListRevocationsRequest\x12%\n\x0esubject_filter\x18\x01 \x01(\tR\rsubjectFilter\x12\x42\n\rreason_filter\x18\x02 \x01(\x0e\x32\x1d.capiscio.v1.RevocationReasonR\x0creasonFilter\x12\x14\n\x05limit\x18\x03 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x04 \x01(\tR\x06\x63ursor\"\x93\x01\n\x17ListRevocationsResponse\x12\x36\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1c.capiscio.v1.RevocationEntryR\x07\x65ntries\x12\x1f\n\x0bnext_cursor\x18\x02 \x01(\tR\nnextCursor\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\"_\n\x1a\x46\x65tchRevocationListRequest\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12/\n\x07timeout\x18\x02 \x01(\x0b\x32\x15.capiscio.v1.DurationR\x07timeout\"\xc7\x01\n\x1b\x46\x65tchRevocationListResponse\x12#\n\rentries_added\x18\x01 \x01(\x05R\x0c\x65ntriesAdded\x12\'\n\x0f\x65ntries_updated\x18\x02 \x01(\x05R\x0e\x65ntriesUpdated\x12\x35\n\nfetched_at\x18\x03 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\tfetchedAt\x12#\n\rerror_message\x18\x04 \x01(\tR\x0c\x65rrorMessage\"8\n\x11\x43learCacheRequest\x12#\n\rsource_filter\x18\x01 \x01(\tR\x0csourceFilter\"=\n\x12\x43learCacheResponse\x12\'\n\x0f\x65ntries_cleared\x18\x01 \x01(\x05R\x0e\x65ntriesCleared\"\x16\n\x14GetCacheStatsRequest\"\xa9\x03\n\x15GetCacheStatsResponse\x12#\n\rtotal_entries\x18\x01 \x01(\x05R\x0ctotalEntries\x12#\n\rlocal_entries\x18\x02 \x01(\x05R\x0clocalEntries\x12%\n\x0eremote_entries\x18\x03 \x01(\x05R\rremoteEntries\x12\x42\n\x11last_remote_fetch\x18\x04 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\x0flastRemoteFetch\x12\x32\n\tcache_ttl\x18\x05 \x01(\x0b\x32\x15.capiscio.v1.DurationR\x08\x63\x61\x63heTtl\x12\x63\n\x11\x65ntries_by_source\x18\x06 \x03(\x0b\x32\x37.capiscio.v1.GetCacheStatsResponse.EntriesBySourceEntryR\x0f\x65ntriesBySource\x1a\x42\n\x14\x45ntriesBySourceEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01*\x81\x02\n\x10RevocationReason\x12!\n\x1dREVOCATION_REASON_UNSPECIFIED\x10\x00\x12$\n REVOCATION_REASON_KEY_COMPROMISE\x10\x01\x12)\n%REVOCATION_REASON_AFFILIATION_CHANGED\x10\x02\x12 \n\x1cREVOCATION_REASON_SUPERSEDED\x10\x03\x12,\n(REVOCATION_REASON_CESSATION_OF_OPERATION\x10\x04\x12)\n%REVOCATION_REASON_PRIVILEGE_WITHDRAWN\x10\x05\x32\xda\x04\n\x11RevocationService\x12J\n\tIsRevoked\x12\x1d.capiscio.v1.IsRevokedRequest\x1a\x1e.capiscio.v1.IsRevokedResponse\x12\x41\n\x06Revoke\x12\x1a.capiscio.v1.RevokeRequest\x1a\x1b.capiscio.v1.RevokeResponse\x12G\n\x08Unrevoke\x12\x1c.capiscio.v1.UnrevokeRequest\x1a\x1d.capiscio.v1.UnrevokeResponse\x12\\\n\x0fListRevocations\x12#.capiscio.v1.ListRevocationsRequest\x1a$.capiscio.v1.ListRevocationsResponse\x12h\n\x13\x46\x65tchRevocationList\x12\'.capiscio.v1.FetchRevocationListRequest\x1a(.capiscio.v1.FetchRevocationListResponse\x12M\n\nClearCache\x12\x1e.capiscio.v1.ClearCacheRequest\x1a\x1f.capiscio.v1.ClearCacheResponse\x12V\n\rGetCacheStats\x12!.capiscio.v1.GetCacheStatsRequest\x1a\".capiscio.v1.GetCacheStatsResponseB\xb5\x01\n\x0f\x63om.capiscio.v1B\x0fRevocationProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.revocation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\017RevocationProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_GETCACHESTATSRESPONSE_ENTRIESBYSOURCEENTRY']._loaded_options = None
  _globals['_GETCACHESTATSRESPONSE_ENTRIESBYSOURCEENTRY']._serialized_options = b'8\001'
  _globals['_REVOCATIONREASON']._serialized_start=2160
  _globals['_REVOCATIONREASON']._serialized_end=2417
  _globals['_REVOCATIONENTRY']._serialized_start=72
  _globals['_REVOCATIONENTRY']._serialized_end=330
  _globals['_ISREVOKEDREQUEST']._serialized_start=333
  _globals['_ISREVOKEDREQUEST']._serialized_end=461
  _globals['_ISREVOKEDRESPONSE']._serialized_start=463
  _globals['_ISREVOKEDRESPONSE']._serialized_end=589
  _globals['_REVOKEREQUEST']._serialized_start=591
  _globals['_REVOKEREQUEST']._serialized_end=713
  _globals['_REVOKERESPONSE']._serialized_start=715
  _globals['_REVOKERESPONSE']._serialized_end=820
  _globals['_UNREVOKEREQUEST']._serialized_start=822
  _globals['_UNREVOKEREQUEST']._serialized_end=865
  _globals['_UNREVOKERESPONSE']._serialized_start=867
  _globals['_UNREVOKERESPONSE']._serialized_end=955
  _globals['_LISTREVOCATIONSREQUEST']._serialized_start=958
  _globals['_LISTREVOCATIONSREQUEST']._serialized_end=1135
  _globals['_LISTREVOCATIONSRESPONSE']._serialized_start=1138
  _globals['_LISTREVOCATIONSRESPONSE']._serialized_end=1285
  _globals['_FETCHREVOCATIONLISTREQUEST']._serialized_start=1287
  _globals['_FETCHREVOCATIONLISTREQUEST']._serialized_end=1382
  _globals['_FETCHREVOCATIONLISTRESPONSE']._serialized_start=1385
  _globals['_FETCHREVOCATIONLISTRESPONSE']._serialized_end=1584
  _globals['_CLEARCACHEREQUEST']._serialized_start=1586
  _globals['_CLEARCACHEREQUEST']._serialized_end=1642
  _globals['_CLEARCACHERESPONSE']._serialized_start=1644
  _globals['_CLEARCACHERESPONSE']._serialized_end=1705
  _globals['_GETCACHESTATSREQUEST']._serialized_start=1707
  _globals['_GETCACHESTATSREQUEST']._serialized_end=1729
  _globals['_GETCACHESTATSRESPONSE']._serialized_start=1732
  _globals['_GETCACHESTATSRESPONSE']._serialized_end=2157
  _globals['_GETCACHESTATSRESPONSE_ENTRIESBYSOURCEENTRY']._serialized_start=2091
  _globals['_GETCACHESTATSRESPONSE_ENTRIESBYSOURCEENTRY']._serialized_end=2157
  _globals['_REVOCATIONSERVICE']._serialized_start=2420
  _globals['_REVOCATIONSERVICE']._serialized_end=3022
# @@protoc_insertion_point(module_scope)
