# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/did.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/did.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63\x61piscio/v1/did.proto\x12\x0b\x63\x61piscio.v1\"w\n\x03\x44ID\x12\x10\n\x03raw\x18\x01 \x01(\tR\x03raw\x12\x16\n\x06method\x18\x02 \x01(\tR\x06method\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\x12\x12\n\x04path\x18\x04 \x03(\tR\x04path\x12\x1a\n\x08\x66ragment\x18\x05 \x01(\tR\x08\x66ragment\"#\n\x0fParseDIDRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\"[\n\x10ParseDIDResponse\x12\"\n\x03\x64id\x18\x01 \x01(\x0b\x32\x10.capiscio.v1.DIDR\x03\x64id\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"G\n\x12NewAgentDIDRequest\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x19\n\x08\x61gent_id\x18\x02 \x01(\tR\x07\x61gentId\"L\n\x13NewAgentDIDResponse\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"7\n\x1aNewCapiscIOAgentDIDRequest\x12\x19\n\x08\x61gent_id\x18\x01 \x01(\tR\x07\x61gentId\"&\n\x12\x44ocumentURLRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\"L\n\x13\x44ocumentURLResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"%\n\x11IsAgentDIDRequest\x12\x10\n\x03\x64id\x18\x01 \x01(\tR\x03\x64id\"Q\n\x12IsAgentDIDResponse\x12 \n\x0cis_agent_did\x18\x01 \x01(\x08R\nisAgentDid\x12\x19\n\x08\x61gent_id\x18\x02 \x01(\tR\x07\x61gentId2\xa7\x03\n\nDIDService\x12\x44\n\x05Parse\x12\x1c.capiscio.v1.ParseDIDRequest\x1a\x1d.capiscio.v1.ParseDIDResponse\x12P\n\x0bNewAgentDID\x12\x1f.capiscio.v1.NewAgentDIDRequest\x1a .capiscio.v1.NewAgentDIDResponse\x12`\n\x13NewCapiscIOAgentDID\x12\'.capiscio.v1.NewCapiscIOAgentDIDRequest\x1a .capiscio.v1.NewAgentDIDResponse\x12P\n\x0b\x44ocumentURL\x12\x1f.capiscio.v1.DocumentURLRequest\x1a .capiscio.v1.DocumentURLResponse\x12M\n\nIsAgentDID\x12\x1e.capiscio.v1.IsAgentDIDRequest\x1a\x1f.capiscio.v1.IsAgentDIDResponseB\xae\x01\n\x0f\x63om.capiscio.v1B\x08\x44idProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.did_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\010DidProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_DID']._serialized_start=38
  _globals['_DID']._serialized_end=157
  _globals['_PARSEDIDREQUEST']._serialized_start=159
  _globals['_PARSEDIDREQUEST']._serialized_end=194
  _globals['_PARSEDIDRESPONSE']._serialized_start=196
  _globals['_PARSEDIDRESPONSE']._serialized_end=287
  _globals['_NEWAGENTDIDREQUEST']._serialized_start=289
  _globals['_NEWAGENTDIDREQUEST']._serialized_end=360
  _globals['_NEWAGENTDIDRESPONSE']._serialized_start=362
  _globals['_NEWAGENTDIDRESPONSE']._serialized_end=438
  _globals['_NEWCAPISCIOAGENTDIDREQUEST']._serialized_start=440
  _globals['_NEWCAPISCIOAGENTDIDREQUEST']._serialized_end=495
  _globals['_DOCUMENTURLREQUEST']._serialized_start=497
  _globals['_DOCUMENTURLREQUEST']._serialized_end=535
  _globals['_DOCUMENTURLRESPONSE']._serialized_start=537
  _globals['_DOCUMENTURLRESPONSE']._serialized_end=613
  _globals['_ISAGENTDIDREQUEST']._serialized_start=615
  _globals['_ISAGENTDIDREQUEST']._serialized_end=652
  _globals['_ISAGENTDIDRESPONSE']._serialized_start=654
  _globals['_ISAGENTDIDRESPONSE']._serialized_end=735
  _globals['_DIDSERVICE']._serialized_start=738
  _globals['_DIDSERVICE']._serialized_end=1161
# @@protoc_insertion_point(module_scope)
