# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: capiscio/v1/simpleguard.proto
# Protobuf Python Version: 6.33.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    4,
    '',
    'capiscio/v1/simpleguard.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capiscio_mcp._proto.gen.capiscio.v1 import common_pb2 as capiscio_dot_v1_dot_common__pb2
from capiscio_mcp._proto.gen.capiscio.v1 import trust_pb2 as capiscio_dot_v1_dot_trust__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63\x61piscio/v1/simpleguard.proto\x12\x0b\x63\x61piscio.v1\x1a\x18\x63\x61piscio/v1/common.proto\x1a\x17\x63\x61piscio/v1/trust.proto\"\xf1\x01\n\x0bSignRequest\x12\x18\n\x07payload\x18\x01 \x01(\x0cR\x07payload\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x34\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x1c.capiscio.v1.SignatureFormatR\x06\x66ormat\x12?\n\x07headers\x18\x04 \x03(\x0b\x32%.capiscio.v1.SignRequest.HeadersEntryR\x07headers\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"|\n\x0cSignResponse\x12\x1c\n\tsignature\x18\x01 \x01(\x0cR\tsignature\x12)\n\x10signature_string\x18\x02 \x01(\tR\x0fsignatureString\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"\x9b\x01\n\rVerifyRequest\x12\x18\n\x07payload\x18\x01 \x01(\x0cR\x07payload\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12)\n\x10signature_string\x18\x03 \x01(\tR\x0fsignatureString\x12\'\n\x0f\x65xpected_signer\x18\x04 \x01(\tR\x0e\x65xpectedSigner\"\xc0\x01\n\x0eVerifyResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x1d\n\nsigner_did\x18\x02 \x01(\tR\tsignerDid\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\x12=\n\nvalidation\x18\x04 \x01(\x0b\x32\x1d.capiscio.v1.ValidationResultR\nvalidation\x12#\n\rerror_message\x18\x05 \x01(\tR\x0c\x65rrorMessage\"\xa8\x02\n\x13SignAttachedRequest\x12\x18\n\x07payload\x18\x01 \x01(\x0cR\x07payload\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x34\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x1c.capiscio.v1.SignatureFormatR\x06\x66ormat\x12G\n\x07headers\x18\x04 \x03(\x0b\x32-.capiscio.v1.SignAttachedRequest.HeadersEntryR\x07headers\x12%\n\x0e\x64\x65tach_payload\x18\x05 \x01(\x08R\rdetachPayload\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"M\n\x14SignAttachedResponse\x12\x10\n\x03jws\x18\x01 \x01(\tR\x03jws\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"}\n\x15VerifyAttachedRequest\x12\x10\n\x03jws\x18\x01 \x01(\tR\x03jws\x12)\n\x10\x64\x65tached_payload\x18\x02 \x01(\x0cR\x0f\x64\x65tachedPayload\x12\'\n\x0f\x65xpected_signer\x18\x03 \x01(\tR\x0e\x65xpectedSigner\"\xe2\x01\n\x16VerifyAttachedResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\x12\x1d\n\nsigner_did\x18\x03 \x01(\tR\tsignerDid\x12\x15\n\x06key_id\x18\x04 \x01(\tR\x05keyId\x12=\n\nvalidation\x18\x05 \x01(\x0b\x32\x1d.capiscio.v1.ValidationResultR\nvalidation\x12#\n\rerror_message\x18\x06 \x01(\tR\x0c\x65rrorMessage\"\xf4\x01\n\x16GenerateKeyPairRequest\x12\x37\n\talgorithm\x18\x01 \x01(\x0e\x32\x19.capiscio.v1.KeyAlgorithmR\talgorithm\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12M\n\x08metadata\x18\x03 \x03(\x0b\x32\x31.capiscio.v1.GenerateKeyPairRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xb5\x02\n\x17GenerateKeyPairResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1d\n\npublic_key\x18\x02 \x01(\x0cR\tpublicKey\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12$\n\x0epublic_key_pem\x18\x04 \x01(\tR\x0cpublicKeyPem\x12&\n\x0fprivate_key_pem\x18\x05 \x01(\tR\rprivateKeyPem\x12\x37\n\talgorithm\x18\x06 \x01(\x0e\x32\x19.capiscio.v1.KeyAlgorithmR\talgorithm\x12#\n\rerror_message\x18\x07 \x01(\tR\x0c\x65rrorMessage\x12\x17\n\x07\x64id_key\x18\x08 \x01(\tR\x06\x64idKey\"}\n\x0eLoadKeyRequest\x12\x1b\n\tfile_path\x18\x01 \x01(\tR\x08\x66ilePath\x12.\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x16.capiscio.v1.KeyFormatR\x06\x66ormat\x12\x1e\n\npassphrase\x18\x03 \x01(\tR\npassphrase\"\xae\x01\n\x0fLoadKeyResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x37\n\talgorithm\x18\x02 \x01(\x0e\x32\x19.capiscio.v1.KeyAlgorithmR\talgorithm\x12&\n\x0fhas_private_key\x18\x03 \x01(\x08R\rhasPrivateKey\x12#\n\rerror_message\x18\x04 \x01(\tR\x0c\x65rrorMessage\"\xbf\x01\n\x10\x45xportKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1b\n\tfile_path\x18\x02 \x01(\tR\x08\x66ilePath\x12.\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x16.capiscio.v1.KeyFormatR\x06\x66ormat\x12\'\n\x0finclude_private\x18\x04 \x01(\x08R\x0eincludePrivate\x12\x1e\n\npassphrase\x18\x05 \x01(\tR\npassphrase\"U\n\x11\x45xportKeyResponse\x12\x1b\n\tfile_path\x18\x01 \x01(\tR\x08\x66ilePath\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"*\n\x11GetKeyInfoRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\"\xb5\x03\n\x12GetKeyInfoResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x37\n\talgorithm\x18\x02 \x01(\x0e\x32\x19.capiscio.v1.KeyAlgorithmR\talgorithm\x12&\n\x0fhas_private_key\x18\x03 \x01(\x08R\rhasPrivateKey\x12\x1d\n\npublic_key\x18\x04 \x01(\x0cR\tpublicKey\x12$\n\x0epublic_key_pem\x18\x05 \x01(\tR\x0cpublicKeyPem\x12\x35\n\ncreated_at\x18\x06 \x01(\x0b\x32\x16.capiscio.v1.TimestampR\tcreatedAt\x12I\n\x08metadata\x18\x07 \x03(\x0b\x32-.capiscio.v1.GetKeyInfoResponse.MetadataEntryR\x08metadata\x12#\n\rerror_message\x18\x08 \x01(\tR\x0c\x65rrorMessage\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x8e\x01\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12 \n\x1cSIGNATURE_FORMAT_JWS_COMPACT\x10\x01\x12\x1d\n\x19SIGNATURE_FORMAT_JWS_JSON\x10\x02\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x03\x32\x83\x05\n\x12SimpleGuardService\x12;\n\x04Sign\x12\x18.capiscio.v1.SignRequest\x1a\x19.capiscio.v1.SignResponse\x12\x41\n\x06Verify\x12\x1a.capiscio.v1.VerifyRequest\x1a\x1b.capiscio.v1.VerifyResponse\x12S\n\x0cSignAttached\x12 .capiscio.v1.SignAttachedRequest\x1a!.capiscio.v1.SignAttachedResponse\x12Y\n\x0eVerifyAttached\x12\".capiscio.v1.VerifyAttachedRequest\x1a#.capiscio.v1.VerifyAttachedResponse\x12\\\n\x0fGenerateKeyPair\x12#.capiscio.v1.GenerateKeyPairRequest\x1a$.capiscio.v1.GenerateKeyPairResponse\x12\x44\n\x07LoadKey\x12\x1b.capiscio.v1.LoadKeyRequest\x1a\x1c.capiscio.v1.LoadKeyResponse\x12J\n\tExportKey\x12\x1d.capiscio.v1.ExportKeyRequest\x1a\x1e.capiscio.v1.ExportKeyResponse\x12M\n\nGetKeyInfo\x12\x1e.capiscio.v1.GetKeyInfoRequest\x1a\x1f.capiscio.v1.GetKeyInfoResponseB\xb6\x01\n\x0f\x63om.capiscio.v1B\x10SimpleguardProtoP\x01ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\xa2\x02\x03\x43XX\xaa\x02\x0b\x43\x61piscio.V1\xca\x02\x0b\x43\x61piscio\\V1\xe2\x02\x17\x43\x61piscio\\V1\\GPBMetadata\xea\x02\x0c\x43\x61piscio::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capiscio.v1.simpleguard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.capiscio.v1B\020SimpleguardProtoP\001ZDgithub.com/capiscio/capiscio-core/pkg/rpc/gen/capiscio/v1;capisciov1\242\002\003CXX\252\002\013Capiscio.V1\312\002\013Capiscio\\V1\342\002\027Capiscio\\V1\\GPBMetadata\352\002\014Capiscio::V1'
  _globals['_SIGNREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_SIGNREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_SIGNATTACHEDREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_SIGNATTACHEDREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_GENERATEKEYPAIRREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_GENERATEKEYPAIRREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETKEYINFORESPONSE_METADATAENTRY']._loaded_options = None
  _globals['_GETKEYINFORESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_SIGNATUREFORMAT']._serialized_start=3183
  _globals['_SIGNATUREFORMAT']._serialized_end=3325
  _globals['_SIGNREQUEST']._serialized_start=98
  _globals['_SIGNREQUEST']._serialized_end=339
  _globals['_SIGNREQUEST_HEADERSENTRY']._serialized_start=281
  _globals['_SIGNREQUEST_HEADERSENTRY']._serialized_end=339
  _globals['_SIGNRESPONSE']._serialized_start=341
  _globals['_SIGNRESPONSE']._serialized_end=465
  _globals['_VERIFYREQUEST']._serialized_start=468
  _globals['_VERIFYREQUEST']._serialized_end=623
  _globals['_VERIFYRESPONSE']._serialized_start=626
  _globals['_VERIFYRESPONSE']._serialized_end=818
  _globals['_SIGNATTACHEDREQUEST']._serialized_start=821
  _globals['_SIGNATTACHEDREQUEST']._serialized_end=1117
  _globals['_SIGNATTACHEDREQUEST_HEADERSENTRY']._serialized_start=281
  _globals['_SIGNATTACHEDREQUEST_HEADERSENTRY']._serialized_end=339
  _globals['_SIGNATTACHEDRESPONSE']._serialized_start=1119
  _globals['_SIGNATTACHEDRESPONSE']._serialized_end=1196
  _globals['_VERIFYATTACHEDREQUEST']._serialized_start=1198
  _globals['_VERIFYATTACHEDREQUEST']._serialized_end=1323
  _globals['_VERIFYATTACHEDRESPONSE']._serialized_start=1326
  _globals['_VERIFYATTACHEDRESPONSE']._serialized_end=1552
  _globals['_GENERATEKEYPAIRREQUEST']._serialized_start=1555
  _globals['_GENERATEKEYPAIRREQUEST']._serialized_end=1799
  _globals['_GENERATEKEYPAIRREQUEST_METADATAENTRY']._serialized_start=1740
  _globals['_GENERATEKEYPAIRREQUEST_METADATAENTRY']._serialized_end=1799
  _globals['_GENERATEKEYPAIRRESPONSE']._serialized_start=1802
  _globals['_GENERATEKEYPAIRRESPONSE']._serialized_end=2111
  _globals['_LOADKEYREQUEST']._serialized_start=2113
  _globals['_LOADKEYREQUEST']._serialized_end=2238
  _globals['_LOADKEYRESPONSE']._serialized_start=2241
  _globals['_LOADKEYRESPONSE']._serialized_end=2415
  _globals['_EXPORTKEYREQUEST']._serialized_start=2418
  _globals['_EXPORTKEYREQUEST']._serialized_end=2609
  _globals['_EXPORTKEYRESPONSE']._serialized_start=2611
  _globals['_EXPORTKEYRESPONSE']._serialized_end=2696
  _globals['_GETKEYINFOREQUEST']._serialized_start=2698
  _globals['_GETKEYINFOREQUEST']._serialized_end=2740
  _globals['_GETKEYINFORESPONSE']._serialized_start=2743
  _globals['_GETKEYINFORESPONSE']._serialized_end=3180
  _globals['_GETKEYINFORESPONSE_METADATAENTRY']._serialized_start=1740
  _globals['_GETKEYINFORESPONSE_METADATAENTRY']._serialized_end=1799
  _globals['_SIMPLEGUARDSERVICE']._serialized_start=3328
  _globals['_SIMPLEGUARDSERVICE']._serialized_end=3971
# @@protoc_insertion_point(module_scope)
